@@ -2,13 +2,13 @@
 from __future__ import annotations
 
 import click
-from _pytask.config import hookimpl
+from pytask import hookimpl
 from pytask_parallel.backends import PARALLEL_BACKENDS
 from pytask_parallel.backends import PARALLEL_BACKENDS_DEFAULT
 
 
 @hookimpl
-def pytask_extend_command_line_interface(cli):
+def pytask_extend_command_line_interface(cli: click.Group) -> None:
     """Extend the command line interface."""
     additional_parameters = [
         click.Option(
