@@ -1,10 +1,12 @@
 """Validate command line inputs and configuration values."""
 from __future__ import annotations
 
+from typing import Any
+
 from pytask_parallel.backends import PARALLEL_BACKENDS
 
 
-def n_workers_callback(value):
+def n_workers_callback(value: Any) -> int:
     """Validate the n-workers option."""
     if value == "auto":
         pass
@@ -20,7 +22,7 @@ def n_workers_callback(value):
     return value
 
 
-def parallel_backend_callback(value):
+def parallel_backend_callback(value: Any) -> str | None:
     """Validate the input for the parallel backend."""
     if value in [None, "None", "none"]:
         value = None
@@ -33,7 +35,7 @@ def parallel_backend_callback(value):
     return value
 
 
-def delay_callback(value):
+def delay_callback(value: Any) -> float | None:
     """Validate the delay option."""
     if value in [None, "None", "none"]:
         value = None
